.:TSETMC:. :: BestLimitsAllIns - سفارش های خرید و فروش نمادها برای 5 مظنه برتر

PSB is being developed by Pooya Paridel.
شركت مديريت فناوري بورس تهران
Tehran Securities Exchange Technology Management Co
BestLimitsAllIns - سفارش های خرید و فروش نمادها برای 5 مظنه برتر

آدرس | http://service.tsetmc.com/WebService/TsePublicV2.asmx http://service.tsetmc.com/WebService/TsePublicV2.asmx?WSDL
نام سرويس | BestLimitsAllIns
توضيحات | تقاضاهاي برتر خريد و فروش همه نمادها را ارائه مي کند.
پارامترهاي ورودي |
UserName | نام کاربري مشترک
Password | کلمه عبور مشترک
Flow | کد بازار 0 : عمومي - مشترک بين بورس و فرابورس 1 : بورس 2 : فرابورس 3 : آتی 4 : پایه فرابورس 5 : پایه فرابورس (منتشر نمی شود)
خروجي | Dataset حاوي اطلاعات تقاضاي خريد و فروش با ساختار زير: <xs:schema id="BestLimitsAllIns" xmlns="" xmlns:xs=http://www.w3.org/2001/XMLSchema xmlns:msdata="urn:schemas-microsoft-com:xml-msdata"> <xs:element name="AllBestLimits" msdata:IsDataSet="true" msdata:UseCurrentLocale="true"> <xs:complexType> <xs:choice minOccurs="0" maxOccurs="unbounded"> <xs:element name="InstBestLimit"> <xs:complexType> <xs:sequence> <xs:element name="number" type="xs:unsignedByte" minOccurs="0" /> <xs:element name="InsCode" type="xs:long" minOccurs="0" /> <xs:element name="RefID" type="xs:long" minOccurs="0" /> <xs:element name="YOmOrgTran" type="xs:string" minOccurs="0" /> <xs:element name="QTitMeDem" type="xs:long" minOccurs="0" /> <xs:element name="ZOrdMeDem" type="xs:int" minOccurs="0" /> <xs:element name="PMeDem" type="xs:decimal" minOccurs="0" /> <xs:element name="PMeOf" type="xs:decimal" minOccurs="0" /> <xs:element name="ZOrdMeOf" type="xs:int" minOccurs="0" /> <xs:element name="QTitMeOf" type="xs:long" minOccurs="0" /> </xs:sequence> </xs:complexType> </xs:element> </xs:choice> </xs:complexType> </xs:element> </xs:schema>
اطلاعات خروجي |
number | رديف - براي هر نماد تا 5 مظنه برتر نمايش داده مي شود که اين عدد معرف شماره رديف مظنه است.
InsCode | کد داخلي نماد
QTitMeDem | حجم تقاضا
ZOrdMeDem | تعداد تقاضا
PMeDem | قيمت تقاضا
PMeOf | قيمت عرضه
ZOrdMeOf | تعداد عرضه
QTitMeOf | حجم عرضه